# Changelog

<!--next-version-placeholder-->

## v0.0.7 (2025-03-05)

### Other

* Fixtests ([#19](https://github.com/icecube/skywriter/issues/19)) ([`bd70f32`](https://github.com/icecube/skywriter/commit/bd70f3217adf78c0d4a3213cd2815f6485551a3d))
* Bump python max to 3.13 ([#18](https://github.com/icecube/skywriter/issues/18)) ([`7d7068c`](https://github.com/icecube/skywriter/commit/7d7068cc9cc2d2c10b1fee092ae1f7a1d30df6a0))

## v0.0.6 (2023-10-24)

### Other

* Improve handling of multiple subevents and particle extraction ([#15](https://github.com/icecube/skywriter/issues/15)) ([`c661db9`](https://github.com/icecube/skywriter/commit/c661db97f64d27803b560cd035413e21ea6f1a70))

## v0.0.5 (2023-10-19)

### Other

* Recover keys from original P-frames in `i3_to_json.py` ([#7](https://github.com/icecube/skywriter/issues/7)) ([`cb8137a`](https://github.com/icecube/skywriter/commit/cb8137afff7e6adb35060b8bdfddc5d7d754bde9))

## v0.0.4 (2023-10-16)

### Other

* <bot> update setup.cfg ([`decd9fc`](https://github.com/icecube/skywriter/commit/decd9fc7e7fd9d85d758569a45164fde25317068))
* Set `python_max = 3.11` ([`bb9ad34`](https://github.com/icecube/skywriter/commit/bb9ad343e7629097404fb028aeb7473bd6a4a7e4))
* <bot> update requirements.txt ([`5f11959`](https://github.com/icecube/skywriter/commit/5f119590af32021a18cd5cc2c374cf958c76203a))
* <bot> update requirements-tests.txt ([`895b134`](https://github.com/icecube/skywriter/commit/895b134daa2441625697dccf50f18e8799231ec8))
* <bot> update setup.cfg ([`3f64fb9`](https://github.com/icecube/skywriter/commit/3f64fb9bcf26416c449f2283e77e14fb8fc76e38))
* Use `python-semantic-release/python-semantic-release@v7.34.6` ([`f0f82a7`](https://github.com/icecube/skywriter/commit/f0f82a7d3ecc0f5b9e494c15dd63d6ce02d9acf2))

## v0.0.3 (2023-06-15)

### Other

* Pull true direction from most-energetic in-ice ([#3](https://github.com/icecube/skywriter/issues/3)) ([`68931a7`](https://github.com/icecube/skywriter/commit/68931a7d4c2b855e0566c9eecb6388381b5f7418))

## v0.0.2 (2023-04-18)
### Other
* <bot> update setup.cfg ([`b24681d`](https://github.com/icecube/skywriter/commit/b24681da42771d5b26a8d289bc977cd3ad282830))

## v0.0.1 (2023-04-18)
### Other
* First PR ([#2](https://github.com/icecube/skywriter/issues/2)) ([`615fbfc`](https://github.com/icecube/skywriter/commit/615fbfce7c8e73a2f7584392663b571185a9fc90))
* Initial commit ([`a2fa489`](https://github.com/icecube/skywriter/commit/a2fa4897c1fa30900304c0b03620e6caa455c02d))
